@@ -1,7 +1,6 @@
 package Pcore::API::GitHub;
 
-use Pcore -class;
-use Pcore::API::Response;
+use Pcore -class, -result;
 
 has api_username => ( is => 'ro', isa => Str, required => 1 );
 has api_token    => ( is => 'ro', isa => Str, required => 1 );
@@ -117,16 +116,16 @@ sub create_repo ( $self, @ ) {
             my $api_res;
 
             if ( $res->status != 200 ) {
-                $api_res = Pcore::API::Response->new( { status => $res->status, reason => $res->reason } );
+                $api_res = result [ $res->status, $res->reason ];
             }
             else {
                 my $json = P->data->from_json( $res->body );
 
                 if ( $json->{error} ) {
-                    $api_res = Pcore::API::Response->new( { status => 480, reason => $json->{message} } );
+                    $api_res = result [ 200, $json->{message} ];
                 }
                 else {
-                    $api_res = Pcore::API::Response->new( { status => 200 } );
+                    $api_res = result 200;
                 }
             }
 
@@ -148,9 +147,9 @@ sub create_repo ( $self, @ ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 107                  | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
+## |    3 | 106                  | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 93                   | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
+## |    1 | 92                   | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
