@@ -52,17 +52,13 @@ sub randkey {
     return Pcore::Util::Hash::RandKey->new;
 }
 
+sub limited ($max_size) {
+    state $init = !!require Pcore::Util::Hash::Limited;
+
+    return Pcore::Util::Hash::Limited->new($max_size);
+}
+
 1;
-## -----SOURCE FILTER LOG BEGIN-----
-##
-## PerlCritic profile "pcore-script" policy violations:
-## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
-## | Sev. | Lines                | Policy                                                                                                         |
-## |======+======================+================================================================================================================|
-## |    3 | 21                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
-## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
-##
-## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
