@@ -33,9 +33,10 @@ around new => sub ( $orig, $self, %args ) {
         syntax      => 'Kolon',                                                             # Kolon, TTerse
         module      => [ 'Text::Xslate::Bridge::TT2Like', 'Text::Xslate::Bridge::Star' ],
         function    => {
-            i18n => sub {
-                return i18n( \@_ );
-            },
+
+            # i18n => sub {
+            #     return i18n( \@_ );
+            # },
         },
     };
 
@@ -70,16 +71,6 @@ sub render ( $self, $tmpl, $params = undef ) {
 }
 
 1;
-## -----SOURCE FILTER LOG BEGIN-----
-##
-## PerlCritic profile "pcore-script" policy violations:
-## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
-## | Sev. | Lines                | Policy                                                                                                         |
-## |======+======================+================================================================================================================|
-## |    3 | 42                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
-## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
-##
-## -----SOURCE FILTER LOG END-----
 __END__
 OLD VARS AND FILTERS, maybe needed to be reimplemented:
 
